﻿using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;

namespace WindowsFormsApplication1
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            GridSettings();
            ultraGrid1.DisplayLayout.Override.AllowUpdate = DefaultableBoolean.True;
            ultraGrid1.InitializeLayout += ultraGrid1_InitializeLayout;

            ultraGrid1.DataSource = GetTestPersons();
            
        }

        private UltraDropDown _dropDownColumn;
        public UltraDropDown DropDownColumn
        {
            get
            {
                if (_dropDownColumn == null)
                {
                    _dropDownColumn = new UltraDropDown();
                    DropDownSettings();
                    _dropDownColumn.InitializeLayout += DropDownInitializeLayout;
                }
                return _dropDownColumn;
            }
        }
        
        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            if (e == null) return;

            foreach (var column in e.Layout.Bands[0].Columns)
            {
                if (column.Key == "Test")
                {
                    SetColumnLayout(column);
                }
            }
        }

        private void SetColumnLayout(UltraGridColumn column)
        {
            column.Header.Caption = "Combo Column";
            
            //Edit settings
            column.CellActivation = Activation.AllowEdit;
            column.CellClickAction = CellClickAction.EditAndSelectText;
            column.TabStop = true;
            column.CellDisplayStyle = CellDisplayStyle.FullEditorDisplay;

            //Resize
            column.PerformAutoResize(10, 1);

            var editorSettings = new DefaultEditorOwnerSettings();

            DropDownColumn.ValueMember = "Key";
            DropDownColumn.DisplayMember = "Value";
            DropDownColumn.DataSource = EnumUtil<TestEnum>.Instance.GetEnumDataSource();

            editorSettings.ValueList = DropDownColumn;

            editorSettings.DataType = typeof(TestEnum);
            var editor = new EditorWithCombo(new DefaultEditorOwner(editorSettings));
            column.Editor = editor;
        }

        private void DropDownInitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            foreach (var column in e.Layout.Bands[0].Columns)
            {
                if (column.Key == "Test")
                {
                    column.PerformAutoResize(10, 1);
                }
            }
        }

        #region Dropdown Settings

        private void DropDownSettings()
        {
            DropDownSettingsForGeneralWorkings();
            DropDownSettingsForLayout();
            DropDownSettingsForHeader();
            DropDownSettingsForPerformance();

            _dropDownColumn.Visible = false;
        }

        private void DropDownSettingsForGeneralWorkings()
        {
            _dropDownColumn.DisplayLayout.MaxBandDepth = 1;
            _dropDownColumn.DisplayLayout.NewColumnLoadStyle = NewColumnLoadStyle.Show;
            _dropDownColumn.DisplayLayout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;
            _dropDownColumn.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;
            _dropDownColumn.DisplayLayout.AutoFitStyle = AutoFitStyle.ExtendLastColumn;
            _dropDownColumn.DisplayLayout.ViewStyle = ViewStyle.SingleBand;
        }

        private void DropDownSettingsForLayout()
        {
            Infragistics.Win.Appearance generalAppearance = new Infragistics.Win.Appearance();
            generalAppearance.BackColor = System.Drawing.Color.White;
            generalAppearance.BackColor2 = System.Drawing.Color.White;
            _dropDownColumn.DisplayLayout.Appearance = generalAppearance;

            Infragistics.Win.Appearance activeCellAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance cellAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance rowAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance filterRowAppearance = new Infragistics.Win.Appearance();

            activeCellAppearance.BackColor = SystemColors.Window;
            activeCellAppearance.ForeColor = SystemColors.ControlText;

            cellAppearance.BorderColor = Color.Silver;
            cellAppearance.TextTrimming = Infragistics.Win.TextTrimming.EllipsisCharacter;

            rowAppearance.BackColor = SystemColors.Window;
            rowAppearance.BorderColor = Color.Silver;

            filterRowAppearance.BorderColor = Color.Silver;

            _dropDownColumn.DisplayLayout.Override.FixedRowIndicator = Infragistics.Win.UltraWinGrid.FixedRowIndicator.None;
            _dropDownColumn.DisplayLayout.Override.CellPadding = 0;

            _dropDownColumn.DisplayLayout.Override.BorderStyleCell = Infragistics.Win.UIElementBorderStyle.Dotted;
            _dropDownColumn.DisplayLayout.Override.BorderStyleRow = Infragistics.Win.UIElementBorderStyle.Dotted;

            _dropDownColumn.DisplayLayout.Override.ActiveCellAppearance = activeCellAppearance;
            _dropDownColumn.DisplayLayout.Override.CellAppearance = cellAppearance;

            _dropDownColumn.DisplayLayout.Override.FilterRowSpacingAfter = 4;
            _dropDownColumn.DisplayLayout.Override.FilterRowAppearance = filterRowAppearance;
            _dropDownColumn.DisplayLayout.Override.RowAppearance = rowAppearance;
        }

        private void DropDownSettingsForHeader()
        {
            _dropDownColumn.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortMulti;
            _dropDownColumn.DisplayLayout.Override.HeaderStyle = Infragistics.Win.HeaderStyle.WindowsXPCommand;
        }

        private void DropDownSettingsForPerformance()
        {
            _dropDownColumn.DisplayLayout.Override.CellDisplayStyle = CellDisplayStyle.PlainText;
            _dropDownColumn.DisplayLayout.LoadStyle = LoadStyle.LoadOnDemand;
            _dropDownColumn.DropDownSearchMethod = DropDownSearchMethod.Linear;
            _dropDownColumn.EditAreaDisplayStyle = EditAreaDisplayStyle.DisplayText;
        }

        #endregion

        #region Grid Settings
        private void GridSettings()
        {
            GridBasicSettings();
            SettingsForEditing();
            SettingsForHeader();
            SettingsForActivatingAndSelecting();
            SettingsForFiltering();
            SettingsForPerformance();
        }

        private void GridBasicSettings()
        {
            ultraGrid1.BeginUpdate();
            ultraGrid1.DisplayLayout.MaxBandDepth = 1;
            ultraGrid1.DisplayLayout.AutoFitStyle = Infragistics.Win.UltraWinGrid.AutoFitStyle.ExtendLastColumn;
            ultraGrid1.DisplayLayout.BorderStyle = Infragistics.Win.UIElementBorderStyle.Default;
            ultraGrid1.DisplayLayout.CaptionVisible = Infragistics.Win.DefaultableBoolean.False;

            ultraGrid1.DisplayLayout.ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle.Immediate;
            ultraGrid1.DisplayLayout.ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds.ScrollToFill;
            ultraGrid1.DisplayLayout.MaxRowScrollRegions = 1;
            ultraGrid1.DisplayLayout.MaxColScrollRegions = 1;
            ultraGrid1.DisplayLayout.NewColumnLoadStyle = NewColumnLoadStyle.Show;

            SettingsForEditing();
            SettingsForLayout();
            SettingsForHeader();
            SettingsForActivatingAndSelecting();
            SettingsForFiltering();
            SettingsForPerformance();
            ultraGrid1.EndUpdate();
        }

        private void SettingsForEditing()
        {
            ultraGrid1.DisplayLayout.Override.AllowAddNew = Infragistics.Win.UltraWinGrid.AllowAddNew.No;
            ultraGrid1.DisplayLayout.Override.AllowDelete = Infragistics.Win.DefaultableBoolean.False;
            ultraGrid1.DisplayLayout.Override.AllowUpdate = Infragistics.Win.DefaultableBoolean.False;
        }

        private void SettingsForLayout()
        {
            Infragistics.Win.Appearance generalAppearance = new Infragistics.Win.Appearance();
            generalAppearance.BackColor = System.Drawing.Color.White;
            generalAppearance.BackColor2 = System.Drawing.Color.White;
            ultraGrid1.DisplayLayout.Appearance = generalAppearance;

            Infragistics.Win.Appearance activeCellAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance cellAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance rowAppearance = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance filterRowAppearance = new Infragistics.Win.Appearance();

            activeCellAppearance.BackColor = SystemColors.Window;
            activeCellAppearance.ForeColor = SystemColors.ControlText;

            cellAppearance.BorderColor = Color.Silver;
            cellAppearance.TextTrimming = Infragistics.Win.TextTrimming.EllipsisCharacter;

            rowAppearance.BackColor = SystemColors.Window;
            rowAppearance.BorderColor = Color.Silver;

            
            ultraGrid1.DisplayLayout.Override.FixedRowIndicator = Infragistics.Win.UltraWinGrid.FixedRowIndicator.None;
            ultraGrid1.DisplayLayout.Override.CellPadding = 0;

            ultraGrid1.DisplayLayout.Override.BorderStyleCell = Infragistics.Win.UIElementBorderStyle.Dotted;
            ultraGrid1.DisplayLayout.Override.BorderStyleRow = Infragistics.Win.UIElementBorderStyle.Dotted;

            ultraGrid1.DisplayLayout.Override.ActiveCellAppearance = activeCellAppearance;
            ultraGrid1.DisplayLayout.Override.CellAppearance = cellAppearance;

            ultraGrid1.DisplayLayout.Override.FilterRowSpacingAfter = 4;
            ultraGrid1.DisplayLayout.Override.FilterRowAppearance = filterRowAppearance;
            ultraGrid1.DisplayLayout.Override.RowAppearance = rowAppearance;

        }

        private void SettingsForHeader()
        {
            ultraGrid1.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortMulti;
            ultraGrid1.DisplayLayout.Override.HeaderStyle = Infragistics.Win.HeaderStyle.WindowsXPCommand;
        }

        private void SettingsForActivatingAndSelecting()
        {
            ultraGrid1.DisplayLayout.Override.RowSelectors = Infragistics.Win.DefaultableBoolean.False;
            ultraGrid1.DisplayLayout.Override.CellClickAction = Infragistics.Win.UltraWinGrid.CellClickAction.RowSelect;
            ultraGrid1.DisplayLayout.Override.SelectTypeCell = Infragistics.Win.UltraWinGrid.SelectType.None;
            ultraGrid1.DisplayLayout.Override.SelectTypeRow = Infragistics.Win.UltraWinGrid.SelectType.Single;
        }

        private void SettingsForFiltering()
        {
            ultraGrid1.DisplayLayout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.False;
            ultraGrid1.DisplayLayout.Override.RowFilterAction = Infragistics.Win.UltraWinGrid.RowFilterAction.HideFilteredOutRows;
            ultraGrid1.DisplayLayout.Override.FilterClearButtonLocation = Infragistics.Win.UltraWinGrid.FilterClearButtonLocation.Hidden;
            ultraGrid1.DisplayLayout.Override.FilterEvaluationTrigger = Infragistics.Win.UltraWinGrid.FilterEvaluationTrigger.OnEnterKeyOrLeaveCell;
            ultraGrid1.DisplayLayout.Override.FilterOperandStyle = Infragistics.Win.UltraWinGrid.FilterOperandStyle.Edit;
            ultraGrid1.DisplayLayout.Override.FilterOperatorDefaultValue = Infragistics.Win.UltraWinGrid.FilterOperatorDefaultValue.Contains;
            ultraGrid1.DisplayLayout.Override.FilterOperatorLocation = Infragistics.Win.UltraWinGrid.FilterOperatorLocation.Hidden;
            ultraGrid1.DisplayLayout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
        }

        private void SettingsForPerformance()
        {
            ultraGrid1.DisplayLayout.Override.CellDisplayStyle = CellDisplayStyle.PlainText;
            ultraGrid1.DisplayLayout.ViewStyle = ViewStyle.SingleBand;
            ultraGrid1.DisplayLayout.LoadStyle = Infragistics.Win.UltraWinGrid.LoadStyle.LoadOnDemand;
        }
        #endregion

        private List<Person> GetTestPersons()
        {
            return new List<Person>()
            {
                new Person() {ID = 1, Name = "Test User 1", Test =  TestEnum.Z},
                new Person() {ID = 1, Name = "Test User 2", Test =  TestEnum.A},
                new Person() {ID = 1, Name = "Test User 3", Test =  TestEnum.C},
                new Person() {ID = 1, Name = "Test User 4", Test =  TestEnum.D},
                new Person() {ID = 1, Name = "Test User 5", Test =  TestEnum.G},
                new Person() {ID = 1, Name = "Test User 6", Test =  TestEnum.V},
                new Person() {ID = 1, Name = "Test User 7", Test =  TestEnum.T},
                new Person() {ID = 1, Name = "Test User 8", Test =  TestEnum.O},
                new Person() {ID = 1, Name = "Test User 9", Test =  TestEnum.Q},
                new Person() {ID = 1, Name = "Test User 10", Test =  TestEnum.F},
                new Person() {ID = 1, Name = "Test User 11", Test =  TestEnum.H},
                new Person() {ID = 1, Name = "Test User 12", Test =  TestEnum.B},
                new Person() {ID = 1, Name = "Test User 13", Test =  TestEnum.Z},
                new Person() {ID = 1, Name = "Test User 14", Test =  TestEnum.X},
                new Person() {ID = 1, Name = "Test User 15", Test =  TestEnum.J},
                new Person() {ID = 1, Name = "Test User 16", Test =  TestEnum.I},
                new Person() {ID = 1, Name = "Test User 17", Test =  TestEnum.Y},
                new Person() {ID = 1, Name = "Test User 18", Test =  TestEnum.D}
            };
        }
    }
}
